********************************************************************************
* This code is used to replicate the findings of "Carbon Emissions Trading and Environmental Protection: International Evidence" by Jennie Bai and Hong Ru
* Date: Dec, 2023
********************************************************************************
*version 17.0
clear
set more off
cd "Please put the data and code under the same directory"
log using Ru_Bai_2024.log, replace
********************************************************************************
* Table 1
********************************************************************************
use MergedData.dta,clear
*summary stats in Panel A below
keep if year>=2000 & year<=2020
sum CO2 GHG CO2_percapita GHG_percapita LogETSCap 
*summary stats in Panel B below
keep if year>=2000 & year<=2015
sum Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable
********************************************************************************
* Table 2
********************************************************************************
use MergedData.dta,clear


global Control `"LogGDP_final Logpopulation_WB Unemployment_WB LogRevenue_LCU_IMF LogExpenditure_LCU_IMF LogDebtGross_LCU_IMF LogAgriculture_ValueAdded_WB LogIndustry_ValueAdded_WB LogManufacturing_ValueAdded_WB LogServices_ValueAdded_WB"'

keep if year>=2000 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'

xi $Fixed

* Panel A
cap erase "Table2_PanelA.xls"
cap erase "Table2_PanelA.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using Table2_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' ETS ETS_Pre1 ETS_Pre2 $Control _I*, $Std
}
* Panel B
cap erase "Table2_PanelB.xls"
cap erase "Table2_PanelB.txt"
foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using Table2_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' ETS ETS_Pre1 ETS_Pre2 $Control _I*, $Std
}

********************************************************************************
* Table 3
********************************************************************************
use MergedData.dta,clear

keep if year>=2000 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'

xi $Fixed

keep if ETS==1

* Panel A
cap erase "Table3_PanelA.xls"
cap erase "Table3_PanelA.txt"


foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using Table3_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' LogETSCap $Control _I*, $Std
}

* Panel B
cap erase "Table3_PanelB.xls"
cap erase "Table3_PanelB.txt"

foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using Table3_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' LogETSCap $Control _I*, $Std
}

********************************************************************************
* Table 4
********************************************************************************
use MergedData.dta,clear
keep if year>=1985 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'

xi $Fixed

* Panel A
cap erase "Table4_PanelA.xls"
cap erase "Table4_PanelA.txt"


foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using Table4_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' CarbonTax CarbonTax_Pre1 CarbonTax_Pre2 $Control _I*, $Std
}

* Panel B
cap erase "Table4_PanelB.xls"
cap erase "Table4_PanelB.txt"

foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using Table4_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' CarbonTax CarbonTax_Pre1 CarbonTax_Pre2 $Control _I*, $Std
}

*************************Figure*************************************

********************************************************************
set more off
use MergedData.dta,clear

keep if year>=2000 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'
xi $Fixed


*CarbonExchange_dummy_Pre1 is for 1st year before ETS Launch, and CarbonExchange_dummy_Pre9 is for 9th year before ETS Launch (CarbonExchange_dummy_Pre2 to CarbonExchange_dummy_Pre8 are similary defined). CarbonExchange_dummy_Pre10 is for 10th years before ETS launch and all years before that. 

*CarbonExchange_dummy_Pst1 is for 1st year after ETS Launch, and CarbonExchange_dummy_Pst9 is for 9th year after ETS Launch (CarbonExchange_dummy_Pst2 to CarbonExchange_dummy_Pst8 are similary defined). CarbonExchange_dummy_Pst10 is for 10th years after ETS launch and all years after that. 

global RHS `"CarbonExchange_dummy_Pre10 CarbonExchange_dummy_Pre9 CarbonExchange_dummy_Pre8 CarbonExchange_dummy_Pre7 CarbonExchange_dummy_Pre6 CarbonExchange_dummy_Pre5 CarbonExchange_dummy_Pre4 CarbonExchange_dummy_Pre3 CarbonExchange_dummy_Pre2 CarbonExchange_dummy_Pre1 CarbonExchange_dummy_Pst1 CarbonExchange_dummy_Pst2 CarbonExchange_dummy_Pst3 CarbonExchange_dummy_Pst4 CarbonExchange_dummy_Pst5 CarbonExchange_dummy_Pst6 CarbonExchange_dummy_Pst7 CarbonExchange_dummy_Pst8 CarbonExchange_dummy_Pst9 CarbonExchange_dummy_Pst10"'

************
matrix C = J(3, 21, 1)  
reg LogGHG $RHS $Control _I*, $Std
matrix rownames C = coef ll95 ul95
matrix colnames C = "-10" "-9" "-8" "-7" "-6" "-5" "-4" "-3" "-2" "-1" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "10"
forvalues i=1/21 {
	dis "`i'"
	if `i'<11 {
		matrix C[1,`i'] = r(table)[1,`i'] \ r(table)[5,`i'] \ r(table)[6,`i']
	} 
	else if `i'==11 {
		*matrix C[1,`i'] = 0 \ 0 \ 0
		matrix C[1,`i'] = . \ . \ .
	}
	else {
		matrix C[1,`i'] = r(table)[1,`i'-1] \ r(table)[5,`i'-1] \ r(table)[6,`i'-1]
	}
}  
matrix list C
coefplot matrix(C), ci((C[2] C[3])) vertical yline(0) xline(11, lpattern(dash) lcolor(midgreen)) ytitle("Percentage Change") xtitle("Years relative to ETS Shock") plotregion(fcolor(white)) graphregion(fcolor(white))
graph export Figure1_A.png, width(1280) height(720) replace
***********


************
matrix C = J(3, 21, 1)  
reg LogCO2 $RHS $Control _I*, $Std
matrix rownames C = coef ll95 ul95
matrix colnames C = "-10" "-9" "-8" "-7" "-6" "-5" "-4" "-3" "-2" "-1" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "10"
forvalues i=1/21 {
	dis "`i'"
	if `i'<11 {
		matrix C[1,`i'] = r(table)[1,`i'] \ r(table)[5,`i'] \ r(table)[6,`i']
	} 
	else if `i'==11 {
		*matrix C[1,`i'] = 0 \ 0 \ 0
		matrix C[1,`i'] = . \ . \ .
	}
	else {
		matrix C[1,`i'] = r(table)[1,`i'-1] \ r(table)[5,`i'-1] \ r(table)[6,`i'-1]
	}
}  
matrix list C
coefplot matrix(C), ci((C[2] C[3])) vertical yline(0) xline(11, lpattern(dash) lcolor(midgreen)) ytitle("Percentage Change") xtitle("Years relative to ETS Shock") plotregion(fcolor(white)) graphregion(fcolor(white))
graph export Figure1_B.png, width(1280) height(720) replace
***********

************
matrix C = J(3, 21, 1)  
reg Electricity_Renewable $RHS $Control _I*, $Std
matrix rownames C = coef ll95 ul95
matrix colnames C = "-10" "-9" "-8" "-7" "-6" "-5" "-4" "-3" "-2" "-1" "0" "1" "2" "3" "4" "5" "6" "7" "8" "9" "10"
forvalues i=1/21 {
	dis "`i'"
	if `i'<11 {
		matrix C[1,`i'] = r(table)[1,`i'] \ r(table)[5,`i'] \ r(table)[6,`i']
	} 
	else if `i'==11 {
		*matrix C[1,`i'] = 0 \ 0 \ 0
		matrix C[1,`i'] = . \ . \ .
	}
	else {
		matrix C[1,`i'] = r(table)[1,`i'-1] \ r(table)[5,`i'-1] \ r(table)[6,`i'-1]
	}
}  
matrix list C
coefplot matrix(C), ci((C[2] C[3])) vertical yline(0) xline(11, lpattern(dash) lcolor(midgreen)) ytitle("Percentage Point Change") xtitle("Years relative to ETS Shock") plotregion(fcolor(white)) graphregion(fcolor(white))
graph export Figure2.png, width(1280) height(720) replace
***********

********************************************************************************
* Table A1 for Online Appendix
********************************************************************************
use MergedData.dta,clear
keep if CarbonTax==1
collapse (min) year,by(country)
rename year yearTax
save ttp.dta,replace
use MergedData.dta,clear
keep if ETS==1
collapse (min) year,by(country)
rename year yearETS
joinby country using ttp.dta,unmatched(both)
tab _merge
drop _merge
gen a=3
replace a=1 if yearETS!=. & yearTax!=.
replace a=2 if a!=1 & yearTax!=.
sort a country
drop a
export excel using TableA1.xls, replace

********************************************************************************
* Table A2 for Online Appendix
********************************************************************************

use RGGI.dta,clear

**New Jersey withdrew from RGGI in 2012 but later rejoined the initiative in January 2018.

global FE `"i.year i.gvkey"'
global Std `"cluster(state)"'
global controls `"LogAssets LogSales"'

xi $FE

cap erase "TableA2.xls"
cap erase "TableA2.txt"

foreach x in LogAbsolute_Scope1 LogAbsolute_Scope2 LogAbsolute_GHGDirect LogAbsolute_GHGDirect_Indirect LogIntensityGHGScope2 {
 outreg2 using TableA2.xls, e(all) excel bdec(3) drop(_I* o.*): reg `x' RGGI RGGI_pre1 RGGI_pre2 $controls _I*, $Std
}
 
********************************************************************************
* Table A3 for Online Appendix
********************************************************************************
set more off
use MergedData.dta,clear
keep if CarbonTax==1
collapse (min) year,by(country)
rename year yearTax
save ttp.dta,replace
use MergedData.dta,clear
keep if ETS==1
collapse (min) year,by(country)
rename year yearETS
save tttp.dta,replace
use MergedData.dta, clear
joinby country using ttp.dta,unmatched(master)
tab _merge
drop _merge
joinby country using tttp.dta,unmatched(master)
tab _merge
drop _merge
***********select sample for Tax before ETS
drop if yearTax==.
drop if yearTax>yearETS & yearTax!=. & yearETS!=.
keep if year>=1985 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'


xi $Fixed

cap erase "TableA3.xls"
cap erase "TableA3.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using TableA3.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' CarbonTax ETS $Control _I*, $Std
}

********************************************************************************
* Table A4 for Online Appendix
********************************************************************************
use MergedData.dta,clear
keep if year>=1985 & year<=2020
global Fixed `"i.year i.Country_id"'
global Std `"robust"'

xi $Fixed

drop if CarbonTax==0


*Panel A
cap erase "TableA4_PanelA.xls"
cap erase "TableA4_PanelA.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using TableA4_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_Mean $Control _I*, $Std
}

*Panel B
cap erase "TableA4_PanelB.xls"
cap erase "TableA4_PanelB.txt"
foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using TableA4_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_Mean $Control _I*, $Std
}

********************************************************************************
* Table A5 for Online Appendix
********************************************************************************

*Panel A
cap erase "TableA5_PanelA.xls"
cap erase "TableA5_PanelA.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using TableA5_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_High $Control _I*, $Std
}
*Panel B
cap erase "TableA5_PanelB.xls"
cap erase "TableA5_PanelB.txt"
foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using TableA5_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_High $Control _I*, $Std
}

********************************************************************************
* Table A6 for Online Appendix
********************************************************************************
*Panel A
cap erase "TableA6_PanelA.xls"
cap erase "TableA6_PanelA.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using TableA6_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_High_Lag $Control _I*, $Std
}
*Panel B
cap erase "TableA6_PanelB.xls"
cap erase "TableA6_PanelB.txt"
foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using TableA6_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' Carbon_Tax_High_Lag $Control _I*, $Std
}
********************************************************************************
* Table A7 for Online Appendix
********************************************************************************


*Panel A
cap erase "TableA7_PanelA.xls"
cap erase "TableA7_PanelA.txt"

foreach LHS in LogCO2 LogGHG LogCO2_percapita LogGHG_percapita {
    outreg2 using TableA7_PanelA.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' CarbonTax_Cover $Control _I*, $Std
}

*Panel B
cap erase "TableA7_PanelB.xls"
cap erase "TableA7_PanelB.txt"
foreach LHS in Electricity_Coal Electricity_OilGasCoal Electricity_Nuclear Electricity_Hydroelectric Electricity_Renewable {
    outreg2 using TableA7_PanelB.xls, e(all) excel bdec(3) drop(_I* o.*): reg `LHS' CarbonTax_Cover $Control _I*, $Std
}

log close

********************************************************************************
* End of Code
********************************************************************************
